package com.ruoyi.web.controller.branch;

import java.io.IOException;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.branch.service.ITFileService;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.file.ExcelUtils;
import com.ruoyi.system.service.ISysDictTypeService;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.web.controller.branch.vo.AddPlanVO;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.xssf.usermodel.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.branch.domain.TBranchLearning;
import com.ruoyi.branch.service.ITBranchLearningService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 学习计划Controller
 * 
 * @author ruoyi
 * @date 2023-09-21
 */
@RestController
@RequestMapping("/branch/learning")
public class TBranchLearningController extends BaseController
{
    @Autowired
    private ITBranchLearningService tBranchLearningService;

    @Autowired
    private ISysDictTypeService sysDictTypeService;

    @Autowired
    private ISysUserService userService;

    @PutMapping("/updateLearningTimeStudied")
    public AjaxResult updateLearningTimeStudied(@RequestBody TBranchLearning tBranchLearning)
    {
        tBranchLearning = tBranchLearningService.selectTBranchLearningByLearningId(tBranchLearning.getLearningId());

        Long learningTimeStudied = tBranchLearning.getLearningTimeStudied();
        Long learningTimeRequired = tBranchLearning.getLearningTimeRequired();
        BigDecimal learningProgress = BigDecimal.TEN.multiply(BigDecimal.TEN);
        String learningStatus = null;

        if (learningTimeStudied == null) {
            learningTimeStudied = 1L;
        } else {
            learningTimeStudied += 1L;
        }

        if (learningTimeStudied < learningTimeRequired) {//累计学习时长<规定学习时长，状态=未完成
            learningProgress = learningProgress.multiply(new BigDecimal(learningTimeStudied))
                    .divide(new BigDecimal(learningTimeRequired), 1, RoundingMode.HALF_UP);
            learningStatus = "1";
        } else {//累计学习时长>规定学习时长，状态=已完成
            learningStatus = "2";
            if (tBranchLearning.getSignTime() == null) {//培训完成时间==null，填写当前时间
                tBranchLearning.setSignTime(new Date());
            }
        }

        tBranchLearning.setLearningTimeStudied(learningTimeStudied);
        tBranchLearning.setLearningProgress(learningProgress.toString());
        tBranchLearning.setLearningStatus(learningStatus);

        // 如果学习完成时间==null

        tBranchLearningService.updateTBranchLearning(tBranchLearning);

        return AjaxResult.success(tBranchLearning);
    }


    /**
     * 添加计划
     */
    @PreAuthorize("@ss.hasPermi('branch:learning:add')")
    @Log(title = "学习计划", businessType = BusinessType.INSERT)
    @PostMapping("/addPlan")
    public AjaxResult addPlan(@RequestBody AddPlanVO addPlanVO)
    {
        for (Long userId : addPlanVO.getUserIds()) {
            TBranchLearning tBranchLearning = new TBranchLearning();
            tBranchLearning.setUserId(userId);
            tBranchLearning.setFileId(addPlanVO.getFileId());
            tBranchLearning.setLearningDeadline(addPlanVO.getLearningDeadline());
            tBranchLearning.setLearningTimeRequired(addPlanVO.getLearningTimeRequired());
            tBranchLearning.setDeptId(getDeptId());
            tBranchLearningService.insertTBranchLearning(tBranchLearning);
        }
        return AjaxResult.success();
    }

    /**
     * 查询学习计划列表
     */
    @PreAuthorize("@ss.hasPermi('branch:learning:list')")
    @GetMapping("/list")
    public TableDataInfo list(TBranchLearning tBranchLearning)
    {
        tBranchLearning.setUserId(getUserId());
        startPage();
        List<TBranchLearning> list = tBranchLearningService.selectTBranchLearningList(tBranchLearning);
        return getDataTable(list);
    }

    /**
     * 查询学习计划列表（不分页）
     */
    @PreAuthorize("@ss.hasPermi('branch:learning:list')")
    @GetMapping("/listNoPage")
    public AjaxResult listNoPage(TBranchLearning tBranchLearning)
    {
        return AjaxResult.success(tBranchLearningService.selectTBranchLearningList(tBranchLearning));
    }

    /**
     * 导出签名表
     */
    @PreAuthorize("@ss.hasPermi('branch:learning:export')")
    @Log(title = "学习计划", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TBranchLearning tBranchLearning)
    {
        try {
            List<SysDictData> learningStatus = sysDictTypeService.selectDictDataByType("learning_status");
            List<TBranchLearning> list = tBranchLearningService.selectTBranchLearningList(tBranchLearning);
            for (TBranchLearning branchLearning : list) {
                for (SysDictData data : learningStatus) {
                    if (data.getDictValue().equals(branchLearning.getLearningStatus())) {
                        branchLearning.setLearningStatus(data.getDictLabel());
                    }
                }
            }
            response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
            response.setCharacterEncoding("utf-8");
            XSSFWorkbook workbook = new XSSFWorkbook();
            // 创建工作簿
            XSSFSheet sheet = workbook.createSheet();
            // 标题样式
            CellStyle headerStyle = workbook.createCellStyle();
            headerStyle.setFillForegroundColor(HSSFColor.HSSFColorPredefined.GREY_50_PERCENT.getIndex());//背景颜色
            headerStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);//背景颜色填充
            headerStyle.setAlignment(HorizontalAlignment.CENTER);//居中
            XSSFFont font = workbook.createFont();//字体
            font.setBold(true);//粗体显示
            font.setColor(IndexedColors.WHITE.getIndex());//字体颜色
            headerStyle.setFont(font);
            // 单元格样式
            CellStyle cellStyle = workbook.createCellStyle();
            cellStyle.setAlignment(HorizontalAlignment.CENTER);//居中
            // 设置列宽
            sheet.setColumnWidth(0, 2000);
            sheet.setColumnWidth(1, 10000);
            sheet.setColumnWidth(2, 2000);
            sheet.setColumnWidth(3, 6000);
            sheet.setColumnWidth(4, 6000);
            sheet.setColumnWidth(5, 4000);
            sheet.setColumnWidth(6, 3000);
            sheet.setColumnWidth(7, 6000);
            sheet.setColumnWidth(8, 2000);
            sheet.setColumnWidth(9, 6000);
            // 表头
            XSSFRow row0 = sheet.createRow(0);
            XSSFCell cell0 = row0.createCell(0);
            cell0.setCellValue("姓名");
            cell0.setCellStyle(headerStyle);
            XSSFCell cell1 = row0.createCell(1);
            cell1.setCellValue("课件名称");
            cell1.setCellStyle(headerStyle);
            XSSFCell cell2 = row0.createCell(2);
            cell2.setCellValue("状态");
            cell2.setCellStyle(headerStyle);
            XSSFCell cell3 = row0.createCell(3);
            cell3.setCellValue("规定学习时长（min）");
            cell3.setCellStyle(headerStyle);
            XSSFCell cell4 = row0.createCell(4);
            cell4.setCellValue("累计学习时长（min）");
            cell4.setCellStyle(headerStyle);
            XSSFCell cell5 = row0.createCell(5);
            cell5.setCellValue("截止日期");
            cell5.setCellStyle(headerStyle);
            XSSFCell cell6 = row0.createCell(6);
            cell6.setCellValue("进度（%）");
            cell6.setCellStyle(headerStyle);
            XSSFCell cell7 = row0.createCell(7);
            cell7.setCellValue("培训完成时间");
            cell7.setCellStyle(headerStyle);
            XSSFCell cell8 = row0.createCell(8);
            cell8.setCellValue("签名");
            cell8.setCellStyle(headerStyle);
            XSSFCell cell9 = row0.createCell(9);
            cell9.setCellValue("签名时间");
            cell9.setCellStyle(headerStyle);
            // 创建行
            for (int i = 1; i < list.size() + 1; i++) {
                XSSFRow row = sheet.createRow(i);
                // 创建单元格
                for (int j = 0; j < 10; j++) {
                    XSSFCell cell = row.createCell(j);
                    cell.setCellStyle(cellStyle);
                    switch (j) {
                        case 0:
                            cell.setCellValue(list.get(i - 1).getNickName());
                            break;
                        case 1:
                            cell.setCellValue(list.get(i - 1).getFileName());
                            break;
                        case 2:
                            cell.setCellValue(list.get(i - 1).getLearningStatus());
                            break;
                        case 3:
                            cell.setCellValue(list.get(i - 1).getLearningTimeRequired() + " min");
                            break;
                        case 4:
                            cell.setCellValue(list.get(i - 1).getLearningTimeStudied() + " min");
                            break;
                        case 5:
                            Date learningDeadline = list.get(i - 1).getLearningDeadline();
                            cell.setCellValue(learningDeadline != null ? new SimpleDateFormat("yyyy-MM-dd").format(learningDeadline) : "");
                            break;
                        case 6:
                            cell.setCellValue(list.get(i - 1).getLearningProgress() + "%");
                            break;
                        case 7:
                            Date completeTime = list.get(i - 1).getCompleteTime();
                            cell.setCellValue(completeTime != null ? new SimpleDateFormat("yyyy-MM-dd").format(completeTime) : "");
                            break;
                        case 8:
                            String isSigned = list.get(i - 1).getIsSigned();
                            if (isSigned.equals("1")) {
                                SysUser user = userService.selectUserById(list.get(i - 1).getUserId());
                                String signUrl = user.getSignUrl();
                                System.err.println(signUrl);
                                if (StringUtils.isNotEmpty(signUrl))
                                    ExcelUtils.insertPicture(workbook, sheet, signUrl, i, 8, 1, 1);
                            }
                            break;
                        case 9:
                            Date signTime = list.get(i - 1).getSignTime();
                            cell.setCellValue(signTime != null ? new SimpleDateFormat("yyyy-MM-dd").format(signTime) : "");
                            break;
                    }
                }
            }
            //返回
            workbook.write(response.getOutputStream());
            workbook.close();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 获取学习计划详细信息
     */
    @PreAuthorize("@ss.hasPermi('branch:learning:query')")
    @GetMapping(value = "/{learningId}")
    public AjaxResult getInfo(@PathVariable("learningId") Long learningId)
    {
        return success(tBranchLearningService.selectTBranchLearningByLearningId(learningId));
    }

    /**
     * 新增学习计划
     */
    @PreAuthorize("@ss.hasPermi('branch:learning:add')")
    @Log(title = "学习计划", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TBranchLearning tBranchLearning)
    {
        return toAjax(tBranchLearningService.insertTBranchLearning(tBranchLearning));
    }

    /**
     * 修改学习计划
     */
    @PreAuthorize("@ss.hasPermi('branch:learning:edit')")
    @Log(title = "学习计划", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TBranchLearning tBranchLearning)
    {
        return toAjax(tBranchLearningService.updateTBranchLearning(tBranchLearning));
    }

    /**
     * 删除学习计划
     */
    @PreAuthorize("@ss.hasPermi('branch:learning:remove')")
    @Log(title = "学习计划", businessType = BusinessType.DELETE)
	@DeleteMapping("/{learningIds}")
    public AjaxResult remove(@PathVariable Long[] learningIds)
    {
        return toAjax(tBranchLearningService.deleteTBranchLearningByLearningIds(learningIds));
    }
}
