package com.ruoyi.web.controller.branch;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.branch.domain.approve.DevTask;
import com.ruoyi.common.utils.DateUtils;
import org.activiti.engine.ProcessEngine;
import org.activiti.engine.ProcessEngines;
import org.activiti.engine.RuntimeService;
import org.activiti.engine.TaskService;
import org.activiti.engine.impl.identity.Authentication;
import org.activiti.engine.runtime.ProcessInstance;
import org.activiti.engine.task.Task;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.branch.domain.TBranchLeaveApply;
import com.ruoyi.branch.service.ITBranchLeaveApplyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 请假申请Controller
 * 
 * @author ruoyi
 * @date 2023-09-27
 */
@RestController
@RequestMapping("/branch/leave")
public class TBranchLeaveApplyController extends BaseController
{
    @Autowired
    private ITBranchLeaveApplyService tBranchLeaveApplyService;

    @Autowired
    private RuntimeService runtimeService;

    /**
     * 审批处理
     *
     * @param devTask
     * @return
     */
    @PutMapping("/handle")
    public AjaxResult handle(@RequestBody DevTask devTask) {
        TBranchLeaveApply apply = tBranchLeaveApplyService.selectTBranchLeaveApplyByLeaveId(devTask.getObjId());
        String taskId = devTask.getTaskId();
        String taskName = devTask.getTaskName();
        String condition = devTask.getCondition();
        Map<String, Object> param = new HashMap<>();
        param.put("condition", condition);

        ProcessEngine processEngine = ProcessEngines.getDefaultProcessEngine();
        TaskService taskService = processEngine.getTaskService();
        Task task = taskService.createTaskQuery().taskId(taskId).singleResult();
        String processInstancesId = task.getProcessInstanceId();
        processEngine.getTaskService().claim(taskId, getUserId().toString());
        taskService.complete(taskId, param);

        if (taskName.equals("支部书记审核")) {
            if (condition.equals("1")) {
                apply.setLeaveStatus("2");
            } else if (condition.equals("0")) {
                apply.setLeaveStatus("3");
            }
            apply.setApproveDate(new Date());
        }
        tBranchLeaveApplyService.updateTBranchLeaveApply(apply);

        return AjaxResult.success();
    }

    /**
     * 提交申请
     */
    @PutMapping("/apply/{leaveId}")
    public AjaxResult apply(@PathVariable Long leaveId)
    {
        TBranchLeaveApply tBranchLeaveApply = tBranchLeaveApplyService.selectTBranchLeaveApplyByLeaveId(leaveId);
        String userId = getUserId().toString();

        // 开始流程
        Authentication.setAuthenticatedUserId(userId);
        Map<String, Object> variables = new HashMap<>();
        variables.put("applicant", userId);
        variables.put("verifier", "120");
        long businessKey = tBranchLeaveApply.getLeaveId();
        ProcessInstance pi = runtimeService.startProcessInstanceByKey("branchLeaveApplyProcess", String.valueOf(businessKey), variables);

        // 提交申请
        Map<String, Object> param = new HashMap<>();
        param.put("condition", "1");
        ProcessEngine processEngine = ProcessEngines.getDefaultProcessEngine();
        TaskService taskService = processEngine.getTaskService();
        List<Task> list = taskService.createTaskQuery().taskCandidateOrAssigned(userId).list();
        String taskId = null;
        String processInstanceId = null;
        for (Task task : list) {
            processInstanceId = task.getProcessInstanceId();
            if (processInstanceId.equals(pi.getProcessInstanceId())) {
                taskId = task.getId();
            }
        }
        processEngine.getTaskService().claim(taskId, getUserId().toString());
        taskService.complete(taskId, param);

        tBranchLeaveApply.setProcessId(pi.getProcessInstanceId());
        tBranchLeaveApply.setApNo(DateUtils.dateTimeNow() + userId);
        tBranchLeaveApply.setLeaveStatus("1");
        tBranchLeaveApply.setApplyDate(new Date());
        tBranchLeaveApplyService.updateTBranchLeaveApply(tBranchLeaveApply);

        return AjaxResult.success();
    }

    /**
     * 查询请假申请列表
     */
    @PreAuthorize("@ss.hasPermi('branch:leave:list')")
    @GetMapping("/list")
    public TableDataInfo list(TBranchLeaveApply tBranchLeaveApply)
    {
        startPage();
        List<TBranchLeaveApply> list = tBranchLeaveApplyService.selectTBranchLeaveApplyList(tBranchLeaveApply);
        return getDataTable(list);
    }

    /**
     * 导出请假申请列表
     */
    @PreAuthorize("@ss.hasPermi('branch:leave:export')")
    @Log(title = "请假申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TBranchLeaveApply tBranchLeaveApply)
    {
        List<TBranchLeaveApply> list = tBranchLeaveApplyService.selectTBranchLeaveApplyList(tBranchLeaveApply);
        ExcelUtil<TBranchLeaveApply> util = new ExcelUtil<TBranchLeaveApply>(TBranchLeaveApply.class);
        util.exportExcel(response, list, "请假申请数据");
    }

    /**
     * 获取请假申请详细信息
     */
    @PreAuthorize("@ss.hasPermi('branch:leave:query')")
    @GetMapping(value = "/{leaveId}")
    public AjaxResult getInfo(@PathVariable("leaveId") Long leaveId)
    {
        return success(tBranchLeaveApplyService.selectTBranchLeaveApplyByLeaveId(leaveId));
    }

    /**
     * 新增请假申请
     */
    @PreAuthorize("@ss.hasPermi('branch:leave:add')")
    @Log(title = "请假申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TBranchLeaveApply tBranchLeaveApply)
    {
        tBranchLeaveApply.setUserId(getUserId());
        tBranchLeaveApply.setDeptId(getDeptId());
        tBranchLeaveApply.setLeaveStatus("0");
        return toAjax(tBranchLeaveApplyService.insertTBranchLeaveApply(tBranchLeaveApply));
    }

    /**
     * 修改请假申请
     */
    @PreAuthorize("@ss.hasPermi('branch:leave:edit')")
    @Log(title = "请假申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TBranchLeaveApply tBranchLeaveApply)
    {
        return toAjax(tBranchLeaveApplyService.updateTBranchLeaveApply(tBranchLeaveApply));
    }

    /**
     * 删除请假申请
     */
    @PreAuthorize("@ss.hasPermi('branch:leave:remove')")
    @Log(title = "请假申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{leaveIds}")
    public AjaxResult remove(@PathVariable Long[] leaveIds)
    {
        return toAjax(tBranchLeaveApplyService.deleteTBranchLeaveApplyByLeaveIds(leaveIds));
    }
}
