package com.ruoyi.web.controller.branch;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.SysPost;
import com.ruoyi.system.service.ISysDictTypeService;
import com.ruoyi.system.service.ISysUserService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.branch.domain.TBranchMemHis;
import com.ruoyi.branch.service.ITBranchMemHisService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 年度数据归档Controller
 * 
 * @author ruoyi
 * @date 2023-09-14
 */
@RestController
@RequestMapping("/branch/his")
public class TBranchMemHisController extends BaseController
{
    @Autowired
    private ITBranchMemHisService tBranchMemHisService;

    @Autowired
    private ISysUserService userService;

    @Autowired
    private ISysDictTypeService sysDictTypeService;

    /**
     * 查询年度数据归档列表
     */
    @PreAuthorize("@ss.hasPermi('branch:his:list')")
    @GetMapping("/list")
    public TableDataInfo list(TBranchMemHis tBranchMemHis)
    {
        startPage();
        List<TBranchMemHis> list = tBranchMemHisService.selectTBranchMemHisList(tBranchMemHis);
        TableDataInfo dataTable = getDataTable(list);
        dataTable.setTotal(list.size());
        return dataTable;
    }

    /**
     * 导出年度数据归档列表
     */
    @PreAuthorize("@ss.hasPermi('branch:his:export')")
    @Log(title = "年度数据归档", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TBranchMemHis tBranchMemHis)
    {
        List<SysDictData> memberEducationLevel = sysDictTypeService.selectDictDataByType("member_education_level");
        List<SysDictData> memberEthnic = sysDictTypeService.selectDictDataByType("member_ethnic");
        List<TBranchMemHis> list = tBranchMemHisService.selectTBranchMemHisList(tBranchMemHis);
        for (TBranchMemHis branchMemHis : list) {
            for (SysDictData data : memberEducationLevel) {
                if (data.getDictValue().equals(branchMemHis.getEducationLevel())) {
                    branchMemHis.setEducationLevel(data.getDictLabel());
                }
            }
            for (SysDictData data : memberEthnic) {
                if (data.getDictValue().equals(branchMemHis.getEthnic())) {
                    branchMemHis.setEthnic(data.getDictLabel());
                }
            }
            if (StringUtils.isNotEmpty(branchMemHis.getCurrentMentor())) {
                String name = "";
                for (String s : branchMemHis.getCurrentMentor().split(",")) {
                    SysUser sysUser = userService.selectUserById(Long.valueOf(s));
                    name += sysUser.getNickName() + "、";
                }
                branchMemHis.setCurrentMentor(name.substring(0, name.length() - 1));
            }
            if (CollectionUtils.isNotEmpty(branchMemHis.getPosts())) {
                String postName = "";
                for (SysPost post : branchMemHis.getPosts()) {
                    postName += post.getPostName() + "兼";
                }
                branchMemHis.setCurrentPost(postName.substring(0, postName.length() - 1));
            }
            if (CollectionUtils.isNotEmpty(branchMemHis.getRoles())) {
                String roleName = "";
                for (SysRole role : branchMemHis.getRoles()) {
                    roleName += role.getRoleName() + "兼";
                }
                branchMemHis.setRoleString(roleName.substring(0, roleName.length() - 1));
            }
        }
        ExcelUtil<TBranchMemHis> util = new ExcelUtil<TBranchMemHis>(TBranchMemHis.class);
        util.exportExcel(response, list, "年度数据归档数据");
    }

    /**
     * 获取年度数据归档详细信息
     */
    @PreAuthorize("@ss.hasPermi('branch:his:query')")
    @GetMapping(value = "/{memHisId}")
    public AjaxResult getInfo(@PathVariable("memHisId") Long memHisId)
    {
        return success(tBranchMemHisService.selectTBranchMemHisByMemHisId(memHisId));
    }

    /**
     * 新增年度数据归档
     */
    @PreAuthorize("@ss.hasPermi('branch:his:add')")
    @Log(title = "年度数据归档", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TBranchMemHis tBranchMemHis)
    {
        return toAjax(tBranchMemHisService.insertTBranchMemHis(tBranchMemHis));
    }

    /**
     * 修改年度数据归档
     */
    @PreAuthorize("@ss.hasPermi('branch:his:edit')")
    @Log(title = "年度数据归档", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TBranchMemHis tBranchMemHis)
    {
        return toAjax(tBranchMemHisService.updateTBranchMemHis(tBranchMemHis));
    }

    /**
     * 删除年度数据归档
     */
    @PreAuthorize("@ss.hasPermi('branch:his:remove')")
    @Log(title = "年度数据归档", businessType = BusinessType.DELETE)
	@DeleteMapping("/{memHisIds}")
    public AjaxResult remove(@PathVariable Long[] memHisIds)
    {
        return toAjax(tBranchMemHisService.deleteTBranchMemHisByMemHisIds(memHisIds));
    }
}
