package com.ruoyi.branch.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.branch.mapper.TBranchDuesMapper;
import com.ruoyi.branch.domain.TBranchDues;
import com.ruoyi.branch.service.ITBranchDuesService;

/**
 * 支部党费收支管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-14
 */
@Service
public class TBranchDuesServiceImpl implements ITBranchDuesService 
{
    @Autowired
    private TBranchDuesMapper tBranchDuesMapper;

    /**
     * 查询支部党费收支管理
     * 
     * @param duesId 支部党费收支管理主键
     * @return 支部党费收支管理
     */
    @Override
    public TBranchDues selectTBranchDuesByDuesId(Long duesId)
    {
        return tBranchDuesMapper.selectTBranchDuesByDuesId(duesId);
    }

    /**
     * 查询支部党费收支管理列表
     * 
     * @param tBranchDues 支部党费收支管理
     * @return 支部党费收支管理
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchDues> selectTBranchDuesList(TBranchDues tBranchDues)
    {
        return tBranchDuesMapper.selectTBranchDuesList(tBranchDues);
    }

    /**
     * 新增支部党费收支管理
     * 
     * @param tBranchDues 支部党费收支管理
     * @return 结果
     */
    @Override
    public int insertTBranchDues(TBranchDues tBranchDues)
    {
        tBranchDues.setCreateTime(DateUtils.getNowDate());
        return tBranchDuesMapper.insertTBranchDues(tBranchDues);
    }

    /**
     * 修改支部党费收支管理
     * 
     * @param tBranchDues 支部党费收支管理
     * @return 结果
     */
    @Override
    public int updateTBranchDues(TBranchDues tBranchDues)
    {
        tBranchDues.setUpdateTime(DateUtils.getNowDate());
        return tBranchDuesMapper.updateTBranchDues(tBranchDues);
    }

    /**
     * 批量删除支部党费收支管理
     * 
     * @param duesIds 需要删除的支部党费收支管理主键
     * @return 结果
     */
    @Override
    public int deleteTBranchDuesByDuesIds(Long[] duesIds)
    {
        return tBranchDuesMapper.deleteTBranchDuesByDuesIds(duesIds);
    }

    /**
     * 删除支部党费收支管理信息
     * 
     * @param duesId 支部党费收支管理主键
     * @return 结果
     */
    @Override
    public int deleteTBranchDuesByDuesId(Long duesId)
    {
        return tBranchDuesMapper.deleteTBranchDuesByDuesId(duesId);
    }
}
