package com.ruoyi.branch.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.branch.mapper.TBranchLearningMapper;
import com.ruoyi.branch.domain.TBranchLearning;
import com.ruoyi.branch.service.ITBranchLearningService;

/**
 * 学习计划Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-09-21
 */
@Service
public class TBranchLearningServiceImpl implements ITBranchLearningService 
{
    @Autowired
    private TBranchLearningMapper tBranchLearningMapper;

    /**
     * 查询学习计划
     * 
     * @param learningId 学习计划主键
     * @return 学习计划
     */
    @Override
    public TBranchLearning selectTBranchLearningByLearningId(Long learningId)
    {
        return tBranchLearningMapper.selectTBranchLearningByLearningId(learningId);
    }

    /**
     * 查询学习计划列表
     * 
     * @param tBranchLearning 学习计划
     * @return 学习计划
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchLearning> selectTBranchLearningList(TBranchLearning tBranchLearning)
    {
        return tBranchLearningMapper.selectTBranchLearningList(tBranchLearning);
    }

    /**
     * 新增学习计划
     * 
     * @param tBranchLearning 学习计划
     * @return 结果
     */
    @Override
    public int insertTBranchLearning(TBranchLearning tBranchLearning)
    {
        tBranchLearning.setCreateTime(DateUtils.getNowDate());
        return tBranchLearningMapper.insertTBranchLearning(tBranchLearning);
    }

    /**
     * 修改学习计划
     * 
     * @param tBranchLearning 学习计划
     * @return 结果
     */
    @Override
    public int updateTBranchLearning(TBranchLearning tBranchLearning)
    {
        tBranchLearning.setUpdateTime(DateUtils.getNowDate());
        return tBranchLearningMapper.updateTBranchLearning(tBranchLearning);
    }

    /**
     * 批量删除学习计划
     * 
     * @param learningIds 需要删除的学习计划主键
     * @return 结果
     */
    @Override
    public int deleteTBranchLearningByLearningIds(Long[] learningIds)
    {
        return tBranchLearningMapper.deleteTBranchLearningByLearningIds(learningIds);
    }

    /**
     * 删除学习计划信息
     * 
     * @param learningId 学习计划主键
     * @return 结果
     */
    @Override
    public int deleteTBranchLearningByLearningId(Long learningId)
    {
        return tBranchLearningMapper.deleteTBranchLearningByLearningId(learningId);
    }
}
