package com.ruoyi.branch.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.branch.mapper.TBranchMemHisMapper;
import com.ruoyi.branch.domain.TBranchMemHis;
import com.ruoyi.branch.service.ITBranchMemHisService;

/**
 * 年度数据归档Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-09-14
 */
@Service
public class TBranchMemHisServiceImpl implements ITBranchMemHisService 
{
    @Autowired
    private TBranchMemHisMapper tBranchMemHisMapper;

    /**
     * 查询年度数据归档
     * 
     * @param memHisId 年度数据归档主键
     * @return 年度数据归档
     */
    @Override
    public TBranchMemHis selectTBranchMemHisByMemHisId(Long memHisId)
    {
        return tBranchMemHisMapper.selectTBranchMemHisByMemHisId(memHisId);
    }

    /**
     * 查询年度数据归档列表
     * 
     * @param tBranchMemHis 年度数据归档
     * @return 年度数据归档
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchMemHis> selectTBranchMemHisList(TBranchMemHis tBranchMemHis)
    {
        return tBranchMemHisMapper.selectTBranchMemHisList(tBranchMemHis);
    }

    /**
     * 新增年度数据归档
     * 
     * @param tBranchMemHis 年度数据归档
     * @return 结果
     */
    @Override
    public int insertTBranchMemHis(TBranchMemHis tBranchMemHis)
    {
        tBranchMemHis.setCreateTime(DateUtils.getNowDate());
        return tBranchMemHisMapper.insertTBranchMemHis(tBranchMemHis);
    }

    /**
     * 修改年度数据归档
     * 
     * @param tBranchMemHis 年度数据归档
     * @return 结果
     */
    @Override
    public int updateTBranchMemHis(TBranchMemHis tBranchMemHis)
    {
        tBranchMemHis.setUpdateTime(DateUtils.getNowDate());
        return tBranchMemHisMapper.updateTBranchMemHis(tBranchMemHis);
    }

    /**
     * 批量删除年度数据归档
     * 
     * @param memHisIds 需要删除的年度数据归档主键
     * @return 结果
     */
    @Override
    public int deleteTBranchMemHisByMemHisIds(Long[] memHisIds)
    {
        return tBranchMemHisMapper.deleteTBranchMemHisByMemHisIds(memHisIds);
    }

    /**
     * 删除年度数据归档信息
     * 
     * @param memHisId 年度数据归档主键
     * @return 结果
     */
    @Override
    public int deleteTBranchMemHisByMemHisId(Long memHisId)
    {
        return tBranchMemHisMapper.deleteTBranchMemHisByMemHisId(memHisId);
    }
}
