package com.ruoyi.branch.service.impl;

import java.util.List;

import com.ruoyi.branch.domain.vo.TBranchDyVo;
import com.ruoyi.branch.domain.vo.TBranchJjfzFzdxVo;
import com.ruoyi.branch.domain.vo.TBranchWyhVo;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.branch.mapper.TBranchMemberMapper;
import com.ruoyi.branch.domain.TBranchMember;
import com.ruoyi.branch.service.ITBranchMemberService;

/**
 * 支部成员管理Service业务层处理
 *
 * @author ruoyi
 * @date 2023-06-15
 */
@Service
public class TBranchMemberServiceImpl implements ITBranchMemberService
{
    @Autowired
    private TBranchMemberMapper tBranchMemberMapper;

    /**
     * 查询支部成员管理
     *
     * @param memberId 支部成员管理主键
     * @return 支部成员管理
     */
    @Override
    public TBranchMember selectTBranchMemberByMemberId(Long memberId)
    {
        return tBranchMemberMapper.selectTBranchMemberByMemberId(memberId);
    }

    /**
     * 查询支部成员政治生日列表
     *
     * @param tBranchMember 支部成员管理
     * @return 支部成员管理集合
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchMember> selectPoliticalBirthdayList(TBranchMember tBranchMember)
    {
        return tBranchMemberMapper.selectPoliticalBirthdayList(tBranchMember);
    }

    /**
     * 查询支部成员管理列表
     *
     * @param tBranchMember 支部成员管理
     * @return 支部成员管理
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchMember> selectTBranchMemberList(TBranchMember tBranchMember)
    {
        return tBranchMemberMapper.selectTBranchMemberList(tBranchMember);
    }

    /**
     * 查询支部成员管理列表（党员名册）
     *
     * @param tBranchMember 支部成员管理
     * @return 支部成员管理
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchMember> selectTBranchMemberListDymc(TBranchMember tBranchMember)
    {
        return tBranchMemberMapper.selectTBranchMemberListDymc(tBranchMember);
    }

    /**
     * 新增支部成员管理
     *
     * @param tBranchMember 支部成员管理
     * @return 结果
     */
    @Override
    public int insertTBranchMember(TBranchMember tBranchMember)
    {
        tBranchMember.setCreateTime(DateUtils.getNowDate());
        return tBranchMemberMapper.insertTBranchMember(tBranchMember);
    }

    /**
     * 修改支部成员管理
     *
     * @param tBranchMember 支部成员管理
     * @return 结果
     */
    @Override
    public int updateTBranchMember(TBranchMember tBranchMember)
    {
        tBranchMember.setUpdateTime(DateUtils.getNowDate());
        return tBranchMemberMapper.updateTBranchMember(tBranchMember);
    }

    /**
     * 批量删除支部成员管理
     *
     * @param memberIds 需要删除的支部成员管理主键
     * @return 结果
     */
    @Override
    public int deleteTBranchMemberByMemberIds(Long[] memberIds)
    {
        return tBranchMemberMapper.deleteTBranchMemberByMemberIds(memberIds);
    }

    /**
     * 删除支部成员管理信息
     *
     * @param memberId 支部成员管理主键
     * @return 结果
     */
    @Override
    public int deleteTBranchMemberByMemberId(Long memberId)
    {
        return tBranchMemberMapper.deleteTBranchMemberByMemberId(memberId);
    }

    @Override
    public List<TBranchWyhVo> selectTBranchWyhVoList(TBranchMember tBranchMember) {
        return tBranchMemberMapper.selectTBranchWyhVoList(tBranchMember);
    }

    @Override
    public List<TBranchDyVo> selectTBranchDyVoList(TBranchMember tBranchMember) {
        return tBranchMemberMapper.selectTBranchDyVoList(tBranchMember);
    }

    @Override
    public List<TBranchJjfzFzdxVo> selectTBranchJjfzFzdxVoList(TBranchMember tBranchMember) {
        return tBranchMemberMapper.selectTBranchJjfzFzdxVoList(tBranchMember);
    }
}
