package com.ruoyi.branch.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.branch.mapper.TBranchPlanItemMapper;
import com.ruoyi.branch.domain.TBranchPlanItem;
import com.ruoyi.branch.service.ITBranchPlanItemService;

/**
 * 支部年度工作计划条目Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-17
 */
@Service
public class TBranchPlanItemServiceImpl implements ITBranchPlanItemService 
{
    @Autowired
    private TBranchPlanItemMapper tBranchPlanItemMapper;

    /**
     * 查询支部年度工作计划条目
     * 
     * @param itemId 支部年度工作计划条目主键
     * @return 支部年度工作计划条目
     */
    @Override
    public TBranchPlanItem selectTBranchPlanItemByItemId(Long itemId)
    {
        return tBranchPlanItemMapper.selectTBranchPlanItemByItemId(itemId);
    }

    /**
     * 查询支部年度工作计划条目列表
     * 
     * @param tBranchPlanItem 支部年度工作计划条目
     * @return 支部年度工作计划条目
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchPlanItem> selectTBranchPlanItemList(TBranchPlanItem tBranchPlanItem)
    {
        return tBranchPlanItemMapper.selectTBranchPlanItemList(tBranchPlanItem);
    }

    /**
     * 新增支部年度工作计划条目
     * 
     * @param tBranchPlanItem 支部年度工作计划条目
     * @return 结果
     */
    @Override
    public int insertTBranchPlanItem(TBranchPlanItem tBranchPlanItem)
    {
        tBranchPlanItem.setCreateTime(DateUtils.getNowDate());
        return tBranchPlanItemMapper.insertTBranchPlanItem(tBranchPlanItem);
    }

    /**
     * 修改支部年度工作计划条目
     * 
     * @param tBranchPlanItem 支部年度工作计划条目
     * @return 结果
     */
    @Override
    public int updateTBranchPlanItem(TBranchPlanItem tBranchPlanItem)
    {
        tBranchPlanItem.setUpdateTime(DateUtils.getNowDate());
        return tBranchPlanItemMapper.updateTBranchPlanItem(tBranchPlanItem);
    }

    /**
     * 批量删除支部年度工作计划条目
     * 
     * @param itemIds 需要删除的支部年度工作计划条目主键
     * @return 结果
     */
    @Override
    public int deleteTBranchPlanItemByItemIds(Long[] itemIds)
    {
        return tBranchPlanItemMapper.deleteTBranchPlanItemByItemIds(itemIds);
    }

    /**
     * 删除支部年度工作计划条目信息
     * 
     * @param itemId 支部年度工作计划条目主键
     * @return 结果
     */
    @Override
    public int deleteTBranchPlanItemByItemId(Long itemId)
    {
        return tBranchPlanItemMapper.deleteTBranchPlanItemByItemId(itemId);
    }
}
