package com.ruoyi.branch.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.branch.mapper.TBranchPlanMapper;
import com.ruoyi.branch.domain.TBranchPlan;
import com.ruoyi.branch.service.ITBranchPlanService;

/**
 * 支部年度工作计划Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-17
 */
@Service
public class TBranchPlanServiceImpl implements ITBranchPlanService 
{
    @Autowired
    private TBranchPlanMapper tBranchPlanMapper;

    /**
     * 查询支部年度工作计划
     * 
     * @param planId 支部年度工作计划主键
     * @return 支部年度工作计划
     */
    @Override
    public TBranchPlan selectTBranchPlanByPlanId(Long planId)
    {
        return tBranchPlanMapper.selectTBranchPlanByPlanId(planId);
    }

    /**
     * 查询支部年度工作计划列表
     * 
     * @param tBranchPlan 支部年度工作计划
     * @return 支部年度工作计划
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchPlan> selectTBranchPlanList(TBranchPlan tBranchPlan)
    {
        return tBranchPlanMapper.selectTBranchPlanList(tBranchPlan);
    }

    /**
     * 新增支部年度工作计划
     * 
     * @param tBranchPlan 支部年度工作计划
     * @return 结果
     */
    @Override
    public int insertTBranchPlan(TBranchPlan tBranchPlan)
    {
        tBranchPlan.setCreateTime(DateUtils.getNowDate());
        return tBranchPlanMapper.insertTBranchPlan(tBranchPlan);
    }

    /**
     * 修改支部年度工作计划
     * 
     * @param tBranchPlan 支部年度工作计划
     * @return 结果
     */
    @Override
    public int updateTBranchPlan(TBranchPlan tBranchPlan)
    {
        tBranchPlan.setUpdateTime(DateUtils.getNowDate());
        return tBranchPlanMapper.updateTBranchPlan(tBranchPlan);
    }

    /**
     * 批量删除支部年度工作计划
     * 
     * @param planIds 需要删除的支部年度工作计划主键
     * @return 结果
     */
    @Override
    public int deleteTBranchPlanByPlanIds(Long[] planIds)
    {
        return tBranchPlanMapper.deleteTBranchPlanByPlanIds(planIds);
    }

    /**
     * 删除支部年度工作计划信息
     * 
     * @param planId 支部年度工作计划主键
     * @return 结果
     */
    @Override
    public int deleteTBranchPlanByPlanId(Long planId)
    {
        return tBranchPlanMapper.deleteTBranchPlanByPlanId(planId);
    }
}
