package com.ruoyi.branch.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.branch.mapper.TBranchStudyMapper;
import com.ruoyi.branch.domain.TBranchStudy;
import com.ruoyi.branch.service.ITBranchStudyService;

/**
 * 支部党课学习Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-06-09
 */
@Service
public class TBranchStudyServiceImpl implements ITBranchStudyService 
{
    @Autowired
    private TBranchStudyMapper tBranchStudyMapper;

    /**
     * 查询支部党课学习
     * 
     * @param studyId 支部党课学习主键
     * @return 支部党课学习
     */
    @Override
    public TBranchStudy selectTBranchStudyByStudyId(Long studyId)
    {
        return tBranchStudyMapper.selectTBranchStudyByStudyId(studyId);
    }

    /**
     * 查询支部党课学习列表
     * 
     * @param tBranchStudy 支部党课学习
     * @return 支部党课学习
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchStudy> selectTBranchStudyList(TBranchStudy tBranchStudy)
    {
        return tBranchStudyMapper.selectTBranchStudyList(tBranchStudy);
    }

    /**
     * 新增支部党课学习
     * 
     * @param tBranchStudy 支部党课学习
     * @return 结果
     */
    @Override
    public int insertTBranchStudy(TBranchStudy tBranchStudy)
    {
        tBranchStudy.setCreateTime(DateUtils.getNowDate());
        return tBranchStudyMapper.insertTBranchStudy(tBranchStudy);
    }

    /**
     * 修改支部党课学习
     * 
     * @param tBranchStudy 支部党课学习
     * @return 结果
     */
    @Override
    public int updateTBranchStudy(TBranchStudy tBranchStudy)
    {
        tBranchStudy.setUpdateTime(DateUtils.getNowDate());
        return tBranchStudyMapper.updateTBranchStudy(tBranchStudy);
    }

    /**
     * 批量删除支部党课学习
     * 
     * @param studyIds 需要删除的支部党课学习主键
     * @return 结果
     */
    @Override
    public int deleteTBranchStudyByStudyIds(Long[] studyIds)
    {
        return tBranchStudyMapper.deleteTBranchStudyByStudyIds(studyIds);
    }

    /**
     * 删除支部党课学习信息
     * 
     * @param studyId 支部党课学习主键
     * @return 结果
     */
    @Override
    public int deleteTBranchStudyByStudyId(Long studyId)
    {
        return tBranchStudyMapper.deleteTBranchStudyByStudyId(studyId);
    }
}
